==> gsplot-0.0.5.tar.gz: gsplot-0.0.5/README.md <==
<div align="center">
  <img src="docs/_static/logo/logo_title_gsplot.png" alt="logo_gsplot" width="300">
</div>

[![GitHub Page](https://github.com/SoichiroYamane/gsplot/actions/workflows/gh-pages-sphinx.yml/badge.svg)](https://github.com/SoichiroYamane/gsplot/actions/workflows/gh-pages-sphinx.yml)
![Using Poetry](https://img.shields.io/badge/Using-Poetry-blue)
![PyPI](https://img.shields.io/pypi/v/gsplot)
![PyPI - Downloads](https://img.shields.io/pypi/dm/gsplot)
![Python](https://img.shields.io/badge/python-3.10%2B-blue)
![License: MIT](https://img.shields.io/badge/License-MIT-green)

----------------

<p align="center" style="font-weight: bold; font-size: 1.2em; margin: 20px 0;">
  <a href="https://soichiroyamane.github.io/gsplot/" style="text-decoration: none;">Docs</a> |
  <a href="#authors" style="text-decoration: none;">Authors</a> |
  <a href="#license" style="text-decoration: none;">License</a>
</p>

Welcome to **gsplot** (general-scientific plot), a toolkit designed to enhance the capabilities of data visualization based on [matplotlib](https://matplotlib.org). This package is specifically tailored for creating high-quality figures aimed at the scientific field.

## ✨ Features

- **Better Plot, Less Code**: Simplify the process of creating high-quality figures ⚛️
- **Compatibility**: Compatible with [matplotlib](https://matplotlib.org) 📊
- **Customization**: Customize your configuration to fit your needs 🎨
- **Reproducibility**: Save your package status to make plots reproducible 📦

### 📈 Example using gsplot

[See more details](https://soichiroyamane.github.io/gsplot/guides/demo/4_paper_plot.html)

![example](docs/_static/tutorial/SC_cal.png)

### 🌃 Example with Python REPL 🐍 and neovim 🌟

[See more details](https://soichiroyamane.github.io/gsplot/guides/demo/13_REPL.html)

![repl_tutorial](./docs/_static/tutorial/repl_tutorial_sp.gif)

## 🚀 Getting Started

To use **gsplot**, ensure that you have `Python 3.10+` installed. You can install the package using `pip`:

```bash
pip install gsplot
```

## 👥 Authors

This repository was forked from codes developed by Giordano Mattoni.

- Giordano Mattoni
- Soichiro Yamane

## 📜 License

This project is licensed under the MIT License. See the [LICENSE](./LICENSE) file for details.

==> gsplot-0.0.6.tar.gz: gsplot-0.0.6/README.md <==
<div align="center">
  <img src="docs/_static/logo/logo_title_gsplot.png" alt="logo_gsplot" width="300">
</div>

[![GitHub Page](https://github.com/SoichiroYamane/gsplot/actions/workflows/gh-pages-sphinx.yml/badge.svg)](https://github.com/SoichiroYamane/gsplot/actions/workflows/gh-pages-sphinx.yml)
![Using Poetry](https://img.shields.io/badge/Using-Poetry-blue)
![PyPI](https://img.shields.io/pypi/v/gsplot)
![PyPI - Downloads](https://img.shields.io/pypi/dm/gsplot)
![Python](https://img.shields.io/badge/python-3.10%2B-blue)
![License: MIT](https://img.shields.io/badge/License-MIT-green)

----------------

<p align="center" style="font-weight: bold; font-size: 1.2em; margin: 20px 0;">
  <a href="https://soichiroyamane.github.io/gsplot/stable" style="text-decoration: none;">Docs</a> |
  <a href="#authors" style="text-decoration: none;">Authors</a> |
  <a href="#license" style="text-decoration: none;">License</a>
</p>

Welcome to **gsplot** (general-scientific plot), a toolkit designed to enhance the capabilities of data visualization based on [matplotlib](https://matplotlib.org). This package is specifically tailored for creating high-quality figures aimed at the scientific field.

## ✨ Features

- **Better Plot, Less Code**: Simplify the process of creating high-quality figures ⚛️
- **Compatibility**: Compatible with [matplotlib](https://matplotlib.org) 📊
- **Customization**: Customize your configuration to fit your needs 🎨
- **Reproducibility**: Save your package status to make plots reproducible 📦

### 📈 Example using gsplot

[See more details](https://soichiroyamane.github.io/gsplot/guides/stable/demo/4_paper_plot.html)

![example](docs/_static/tutorial/SC_cal.png)

### 🌃 Example with Python REPL 🐍 and neovim 🌟

[See more details](https://soichiroyamane.github.io/gsplot/stable/guides/demo/13_REPL.html)

![repl_tutorial](./docs/_static/tutorial/repl_tutorial_sp.gif)

## 🚀 Getting Started

To use **gsplot**, ensure that you have `Python 3.10+` installed. You can install the package using `pip`:

```bash
pip install gsplot
```

## 👥 Authors

This repository was forked from codes developed by Giordano Mattoni.

- Giordano Mattoni
- Soichiro Yamane

## 📜 License

This project is licensed under the MIT License. See the [LICENSE](./LICENSE) file for details.
